==> gmic_2.4.5.orig.tar.xz: gmic-2.4.5/gmic-qt/src/InputOutputState.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file InputOutputState.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef _GMIC_QT_INPUTOUTPUTSTATE_H_
#define _GMIC_QT_INPUTOUTPUTSTATE_H_

#include "PreviewMode.h"
#include "gmic_qt.h"

class QJsonObject;

namespace GmicQt
{
struct InputOutputState {
  InputMode inputMode;
  OutputMode outputMode;
  PreviewMode previewMode;

  InputOutputState();
  InputOutputState(InputMode, OutputMode, PreviewMode);
  bool isDefault() const;
  void toJSONObject(QJsonObject &) const;
  static InputOutputState fromJSONObject(const QJsonObject &);
  static const InputOutputState Default;
  static const InputOutputState Unspecified;
  bool operator==(const InputOutputState & other) const;
  bool operator!=(const InputOutputState & other) const;
};
} // namespace GmicQt

#endif // _GMIC_QT_INPUTOUTPUTSTATE_H_

==> gmic_2.9.4.orig.tar.xz: gmic-2.9.4/gmic-qt/src/InputOutputState.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file InputOutputState.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_INPUTOUTPUTSTATE_H
#define GMIC_QT_INPUTOUTPUTSTATE_H

#include "gmic_qt.h"

class QJsonObject;

namespace GmicQt
{
struct InputOutputState {
  InputMode inputMode;
  OutputMode outputMode;
  PreviewMode previewMode;

  InputOutputState();
  InputOutputState(InputMode, OutputMode, PreviewMode);
  bool isDefault() const;
  void toJSONObject(QJsonObject &) const;
  static InputOutputState fromJSONObject(const QJsonObject &);
  static const InputOutputState Default;
  static const InputOutputState Unspecified;
  bool operator==(const InputOutputState & other) const;
  bool operator!=(const InputOutputState & other) const;
};
} // namespace GmicQt

#endif // GMIC_QT_INPUTOUTPUTSTATE_H
